#!/bin/sh
# ---------------------------------------------------------------------------
# /var/install/config.d/fhem-update.sh - paramater update script
#
# Creation   :  2018-03-17 Dirk Alberti, howy-1(at)gmx(dot)de
# Last Update:  2019-01-22 Dirk Alberti
#
# Copyright (c) 2018 Dirk Alberti, howy-1(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ---------------------------------------------------------------------------

# set package name
package_name=fhem

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

#exec 2> /tmp/fhem-update-trace$$.log
#set -x

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_FHEM='no'

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        # backup old configfile
        /var/install/bin/backup-file --quiet ${package_name}

        . /etc/config.d/${package_name}
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} "2018-03-18" "Dirk Alberti"
    # -----------------------------------------------------------------------

    #------------------------------------------------------------------------
    printgroup "fhem configuration"
    #------------------------------------------------------------------------

    printvar "START_FHEM"
    printcomment        "Activate FHEM? Use: yes or no"
    } > ${internal_conf_file}

    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ---------------------------------------------------------------------------
# Create the check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
#----------------------------------------------------------------------------
printgpl --check ${package_name} '2018-03-17' 'Dirk Alberti' > /etc/check.d/${package_name}
#----------------------------------------------------------------------------
cat >> /etc/check.d/${package_name} <<EOF
# Variable                          OPT_VARIABLE                        VARIABLE_N            VALUE
START_FHEM                          -                                   -                     YESNO
EOF

    # Set rights for check.d file
    chmod 0600 /etc/check.d/${package_name}
    chown root /etc/check.d/${package_name}
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------

make_config_file /etc/default.d/${package_name}

# Update from old version
rename_old_variables

# Write new config file
make_config_file /etc/config.d/${package_name}

# Write check.d file
make_check_file

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
